
# Gauss CLI

Gauss CLI Tool , it's a package to solve N*N equation with gauss elimination method.
## Demo with  source code

https://replit.com/@messabih-khalil/gaussCLI#main.py


## Installation

to install gauss-cli just run :

```bash
  pip install gauss-cli
```
    
## Usage/Examples

```python
from gaussCLI.gaussCli import GaussCLI
# run gauss cli
gc = GaussCLI()
```


## Screenshots

![App Screenshot](https://mir-s3-cdn-cf.behance.net/project_modules/max_1200/46ac8d157952477.63829b23dfa29.png)
![App Screenshot](https://mir-s3-cdn-cf.behance.net/project_modules/max_1200/785332157952477.63829b23e0ab9.png)
![App Screenshot](https://mir-s3-cdn-cf.behance.net/project_modules/max_1200/6f690a157952477.63829b23e1a80.png)

